# Mara App

[![Build status](https://github.com/mara/mara-app/actions/workflows/build_for_deployment.yaml/badge.svg)](https://github.com/mara/mara-app/actions/workflows/build_for_deployment.yaml)
![PyPI - License](https://img.shields.io/pypi/l/mara-app.svg)
[![PyPI version](https://badge.fury.io/py/mara-app.svg)](https://badge.fury.io/py/mara-app)
[![Slack Status](https://img.shields.io/badge/slack-join_chat-white.svg?logo=slack&style=social)](https://communityinviter.com/apps/mara-users/public-invite)


A flask app for building backends that are distributed across separate packages. Provides
- a Bootstrap 4 based page layout
- auto-detection of flask blueprints
- auto-detection of navigation entries
- auto-detection of click command line interfaces

Please have a look at the [mara example application](https://github.com/mara/mara-example-project-1) for an example of how to use this.

## Links

* Documentation: https://mara-app.readthedocs.io/
* Changes: https://mara-app.readthedocs.io/en/latest/changes.html
* PyPI Releases: https://pypi.org/project/mara-app/
* Source Code: https://github.com/mara/mara-app
* Issue Tracker: https://github.com/mara/mara-app/issues
